#pragma once

#include <stdint.h>
#include <functional>
#include <string>
#include <memory>
#include "AccountDevice.h"

namespace rtx
{
    namespace pcsdk
    {
        // 错误码
        enum RtcxPcCode {
            RTCX_PC_SUCCESS = 0,
            RTCX_PC_FAIL = -1
        };
        // 初始化参数
        struct InitParam
        {
            std::string cfgFileName = "config.ini"; // 配置文件名
            std::string appKey;
            std::string appSecret;
        };
        // 事件回调接口
        class IRtcxPcEvtHandler
        {
        public:
            typedef std::shared_ptr<IRtcxPcEvtHandler> Ptr;

            IRtcxPcEvtHandler() {}

            virtual ~IRtcxPcEvtHandler() {}

            // 上线回调
            virtual void OnConnection(int errCode, const std::string &message) = 0;
        };

        // 接口
        class IRtcxPcApi
        {
        public:
            typedef std::shared_ptr<IRtcxPcApi> Ptr;

            IRtcxPcApi() {}

            virtual ~IRtcxPcApi() {}

            // 初始化
            static int32_t Initialize(const InitParam &param);
            // 反初始化
            static int32_t Uninitialize();
            // 获取版本号
            static int32_t GetVersion(std::string &version);

            // 创建PC API智能指针
            static IRtcxPcApi::Ptr CreateRtcxPcApi(const std::shared_ptr<IRtcxPcEvtHandler> handler);

            // 登入
            virtual int32_t Login(const std::string &userName, const std::string &password) = 0;

            // 登出
            virtual int32_t Logout() = 0;

            // 获取设备列表
            virtual std::shared_ptr<rtx::account::DeviceList> GetDeviceList(const rtx::account::DeviceListReq &deviceListReq) = 0;

            // 获取设备分组列表
            virtual std::shared_ptr<rtx::account::DeviceGroupList> GetDeviceGroupList(const rtx::account::DeviceGroupListReq &deviceGroupListReq) = 0;

            // 开始播放
            virtual void StartPlay(const std::string &deviceName, const std::string &productKey, void *hWnd) = 0;

            // 结束播放
            virtual void StopPlay() = 0;
        };

    }
}
